# The YumBaseCli is organized pretty well with the ability to override I/O
# methods in mind.  But they dropped the ball with the RPMInstallCallback
# class.  It's created and visible only within YumBaseCli.doTransaction, so
# there's no clean way to override it.  Furthermore, it writes directly to
# stdout!
#
# One approach to resolve this is to override sys.stdout and parse its
# output.  But this creates dependencies on exact text from yum, and so it
# would be likely to break with future yum versions.
#
# Another approach is to override the whole RPMInstallCallback class and
# replicate all its code.  But this also creates a dependency on the
# particular version of yum from which the RPMInstallCallback is replicated.
#
# So, instead this code overrides the RPMInstallCallback class, but uses a
# symlink stunt to make the original RPMInstallCallback class available as
# originalCallback.RPMInstallCallback.  So, this class can be derived from
# that and there's no need to replicate that whole class; this class
# overrides just what needs to be overridden.

import originalCallback
import yumIOC

class RPMInstallCallback(originalCallback.RPMInstallCallback):
    def __init__(self, output=1):
        originalCallback.RPMInstallCallback.__init__(self)
        yumIOC.tsInitCallback(output)

    def _localprint(self, msg):
        if self.output:
            yumIOC.log(0, msg)

    def callback(self, what, bytes, total, h, user):
        yumIOC.tsCallback(what, bytes, total, h, user)
        return originalCallback.RPMInstallCallback.callback(self, what, bytes,
                                                            total, h, user)
